==> netbluemind4-4.1.51294.tar.gz: netbluemind4-4.1.51294/netbluemind/mailmessage/api/MailTipFilter.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MailTipFilter :
    def __init__( self):
        self.mailTips = None
        self.filterType = None
        pass

class __MailTipFilterSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = MailTipFilter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mailTipsValue = value['mailTips']
        instance.mailTips = serder.ListSerDer(serder.STRING).parse(mailTipsValue)
        from netbluemind.mailmessage.api.MailTipFilterFilterType import MailTipFilterFilterType
        from netbluemind.mailmessage.api.MailTipFilterFilterType import __MailTipFilterFilterTypeSerDer__
        filterTypeValue = value['filterType']
        instance.filterType = __MailTipFilterFilterTypeSerDer__().parse(filterTypeValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        mailTipsValue = value.mailTips
        instance["mailTips"] = serder.ListSerDer(serder.STRING).encode(mailTipsValue)
        from netbluemind.mailmessage.api.MailTipFilterFilterType import MailTipFilterFilterType
        from netbluemind.mailmessage.api.MailTipFilterFilterType import __MailTipFilterFilterTypeSerDer__
        filterTypeValue = value.filterType
        instance["filterType"] = __MailTipFilterFilterTypeSerDer__().encode(filterTypeValue)
        return instance

==> netbluemind5-5.0.7187.tar.gz: netbluemind5-5.0.7187/netbluemind/mailmessage/api/MailTipFilter.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MailTipFilter:
    def __init__(self):
        self.mailTips = None
        self.filterType = None
        pass


class __MailTipFilterSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailTipFilter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mailTipsValue = value['mailTips']
        instance.mailTips = serder.ListSerDer(
            serder.STRING).parse(mailTipsValue)
        from netbluemind.mailmessage.api.MailTipFilterFilterType import MailTipFilterFilterType
        from netbluemind.mailmessage.api.MailTipFilterFilterType import __MailTipFilterFilterTypeSerDer__
        filterTypeValue = value['filterType']
        instance.filterType = __MailTipFilterFilterTypeSerDer__().parse(filterTypeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        mailTipsValue = value.mailTips
        instance["mailTips"] = serder.ListSerDer(
            serder.STRING).encode(mailTipsValue)
        from netbluemind.mailmessage.api.MailTipFilterFilterType import MailTipFilterFilterType
        from netbluemind.mailmessage.api.MailTipFilterFilterType import __MailTipFilterFilterTypeSerDer__
        filterTypeValue = value.filterType
        instance["filterType"] = __MailTipFilterFilterTypeSerDer__().encode(
            filterTypeValue)
        return instance
